@@ -10,15 +10,15 @@
  */
 #include "tomcrypt.h"
 
-/** 
+/**
   @file pkcs_1_mgf1.c
-  The Mask Generation Function (MGF1) for LTC_PKCS #1, Tom St Denis 
+  The Mask Generation Function (MGF1) for PKCS #1, Tom St Denis
 */
 
 #ifdef LTC_PKCS_1
 
 /**
-   Perform LTC_PKCS #1 MGF1 (internal)
+   Perform PKCS #1 MGF1 (internal)
    @param seed        The seed for MGF1
    @param seedlen     The length of the seed
    @param hash_idx    The index of the hash desired
@@ -35,12 +35,12 @@ int pkcs_1_mgf1(int                  hash_idx,
    int           err;
    hash_state    *md;
    unsigned char *buf;
- 
+
    LTC_ARGCHK(seed != NULL);
    LTC_ARGCHK(mask != NULL);
 
    /* ensure valid hash */
-   if ((err = hash_is_valid(hash_idx)) != CRYPT_OK) { 
+   if ((err = hash_is_valid(hash_idx)) != CRYPT_OK) {
       return err;
    }
 
